===================
terrarium-assembler
===================


.. image:: https://img.shields.io/pypi/v/terrarium_assembler.svg
        :target: https://pypi.python.org/pypi/terrarium_assembler

.. image:: https://img.shields.io/travis/belonesox/terrarium_assembler.svg
        :target: https://travis-ci.com/belonesox/terrarium_assembler

.. image:: https://readthedocs.org/projects/terrarium-assembler/badge/?version=latest
        :target: https://terrarium-assembler.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Generate Portable Linux Applications, 
mostly using python packages and any system package,
that can be run on any Linux,
without Docker, Snap, Flathub, etc.

Just portable folder.


* Free software: MIT license
* Documentation: https://terrarium-assembler.readthedocs.io.


Features
--------

* TODO

Credits
-------

